-- nb_cmd_routines.lua
-- A Lua Module to help control the rotation of a notebook leaf
--  Selden Ball, October, 2016. All rights reserved. 
--
-- ==========================================================
-- the variables here are all globals: preserved between screen refreshes
-- most probably should be table elements, not individual variables.

second =  0.11574074051168E-04

minute = 60 * second
  hour = 60 * minute
   day = 24 * hour -- dam well better be 1.0000 (tested: it is)

-- arbitrary duration for all movements. For some it's too slow, for others it's too fast.
dT = 0.25*second

xAxis = celestia:newvector( 1, 0, 0)
yAxis = celestia:newvector( 0, 1, 0)
zAxis = celestia:newvector( 0, 0, 1)
  xPi = celestia:newrotation( xAxis, math.pi)
  yPi = celestia:newrotation( yAxis, math.pi)
  yPi2 = celestia:newrotation( yAxis, -math.pi/2)
  yR0 = celestia:newrotation( yAxis, 0)
  zPi = celestia:newrotation( zAxis, math.pi)


--====================================================================
-- command functions
--====================================================================


-- ------------------------
-- generic motion functions
-- ------------------------

InitMoveTable = function (obj,first,last)
	obj.T0 = 1e18
	obj.T1 = 0

	obj.P0 = first
	obj.P1 = last

	obj.Pos0 = first
	obj.Pos1 = first

	obj.TPrev = 1e18
	obj.PosPrev = first

	obj.V = 0
end


MoveToP1 = function (obj,mydate)
	obj.Pos0 = obj.PosPrev
	obj.Pos1 = obj.P1
	obj.V = (obj.P1-obj.P0)/dT
	obj.T0 = obj.Tprev
	local sf = math.abs((obj.P1-obj.PosPrev)/(obj.P1-obj.P0))
	obj.T1 = obj.TPrev+dT*sf
end

MoveToP0 = function (obj,mydate)
	obj.Pos0 = obj.PosPrev
	obj.Pos1 = obj.P0
	obj.V = (obj.P0-obj.P1)/dT
	obj.T0 = obj.TPrev
	local sf = math.abs((obj.P0-obj.PosPrev)/(obj.P1-obj.P0))
	obj.T1 = obj.TPrev+dT*sf
end

MoveStop = function (obj,mydate)
	obj.Pos0 = obj.PosPrev
	obj.Pos1 = obj.PosPrev
	obj.V = 0
	obj.T0 = mydate
	obj.T1 = mydate
	obj.TPrev = mydate
end

MoveNearTh = function (p1,p2)
	local delta = math.rad(1)
	if (math.abs(p1-p2) < delta)
	 then return true
	 else return false
	end
end

MoveNow = function (obj,date)
 	local pos
	if (date < obj.T0)
	 then pos = obj.Pos0
     	elseif (date < obj.T1)
      	  then	pos = obj.PosPrev + obj.V*(date-obj.TPrev)
	else pos = obj.Pos1
      	end
	obj.TPrev = date
	obj.PosPrev = pos
	return pos
end

