-- rotate notebook cover spine and front

-- functions to set position parameters

-- table of leaf states

tb_RotateCover = {}

-- ...............
tb_StartCoverAtP0 = function (tbl)

	  tbl.StartPos = math.rad(-93)
	  tbl.LastPos = math.rad(0)

	  tbl.PrevPos = tbl.StartPos

	  tbl.StartT = 1e32
	  tbl.PrevT = tbl.StartT
	  tbl.LastT = 0

	  tbl.V = 0
end

-- ...............
tb_StartCoverAtP1 = function (tbl)

	  tbl.StartPos = math.rad(0)
	  tbl.LastPos = math.rad(-93)

	  tbl.PrevPos = tbl.StartPos

	  tbl.StartT = 1e32
	  tbl.PrevT = tbl.StartT
	  tbl.LastT = 0

	  tbl.V = 0
end

-- default cover state: notebook closed

tb_StartCoverAtP0(tb_RotateCover)

-- ----------------
-- command routines:
-- initialize cover position and velocity
-- ----------------
tb_RotateCoverLeft = function ()
	   tb_StartCoverAtP1(tb_RotateCover)
	   tb_MoveFromPos(tb_RotateCover)
end

tb_RotateCoverRight = function ()
	   tb_StartCoverAtP0(tb_RotateCover)
	   tb_MoveFromPos(tb_RotateCover)
end

--==================================================================
-- now that the functions are defined, one can
-- specify the commands which invoke those functions 
--==================================================================

tb_cmds.tb_nb_open  = tb_RotateCoverRight
tb_cmds.tb_nb_close  = tb_RotateCoverLeft

--==================================================================
-- ScriptedRotation's _Angle function
--==================================================================

Cover_Move = function(date)

	tb_current_date = date
 	local Angle
	if (date < tb_RotateCover.StartT)
	 then
	   Angle = tb_RotateCover.StartPos
     	elseif (date < tb_RotateCover.LastT)
      	  then
	    Angle = tb_RotateCover.PrevPos + tb_RotateCover.V*(date-tb_RotateCover.PrevT)
	else
	  Angle = tb_RotateCover.LastPos
      	end
	tb_RotateCover.PrevT = date
	tb_RotateCover.PrevPos = Angle

 	return  yPi * celestia:newrotation( yAxis, Angle)

end

Cover_Move_Angleproto =
{
   Period    = 1,
}

-- constructor method
function Cover_Move_Angleproto:new(o)
   o = o or {}  -- create table if one not provided
   setmetatable(o, self)
   self.__index = self

   -- set the period to whatever value was specified in the ssc file;
   -- slightly confusing because Celestia is case sensitive--period must
   -- be lowercase, but the field from the ssc file is capitalized.
   o.period = o.Period

   return o
end

-- The orientation function.

function Cover_Move_Angleproto:orientation(tjd)

	local qNow = 	Cover_Move(tjd)
	return qNow.w, qNow.x, qNow.y, qNow.z

end

function Cover_Move_Angle(sscvals)
   -- create a new Cover_Move_Angle rotation object
   return Cover_Move_Angleproto:new(sscvals)
end
