-- rotate notebook leaf

-- functions to set leaf position parameters

-- table of leaf states

tb_current_date = 0

tb_RotateLeaf = {}

-- ...............
tb_StartAtP0 = function (tbl)

	  tbl.StartPos = math.rad(0)
	  tbl.LastPos = math.rad(-180)

	  tbl.PrevPos = tbl.StartPos

	  tbl.StartT = 1e32
	  tbl.PrevT = tbl.StartT
	  tbl.LastT = 0

	  tbl.V = 0
end

-- ...............
tb_StartAtP1 = function (tbl)

	  tbl.StartPos = math.rad(-180)
	  tbl.LastPos = math.rad(0)

	  tbl.PrevPos = tbl.StartPos

	  tbl.StartT = 1e32
	  tbl.PrevT = tbl.StartT
	  tbl.LastT = 0

	  tbl.V = 0
end

-- default leaf position: turning from right to left is more likely
tb_StartAtP1(tb_RotateLeaf)

-- ----------------
tb_MoveFromPos = function (tbl)
	tbl.V = (tbl.LastPos-tbl.StartPos)/dT
	tbl.PrevT = tb_current_date
	tbl.StartT = tbl.PrevT
	tbl.LastT = tbl.StartT+dT
end
-- ----------------
-- command routines:
-- initialize leaf position and velocity
-- ----------------
tb_RotateLeafLeft = function ()
           celestia:find("tb_rotate_leaf"):setvisible(true)
	   tb_StartAtP1(tb_RotateLeaf)
	   tb_MoveFromPos(tb_RotateLeaf)
end

tb_RotateLeafRight = function ()
-- force selection of non-command
           celestia:find("tb_rotate_leaf"):setvisible(true)
	   tb_StartAtP0(tb_RotateLeaf)
	   tb_MoveFromPos(tb_RotateLeaf)
end

--==================================================================
-- now that the functions are defined, one can
-- specify the commands which invoke those functions 
--==================================================================

tb_cmds.tb_trecto  = tb_RotateLeafLeft
tb_cmds.tb_tverso  = tb_RotateLeafRight

--==================================================================
-- ScriptedRotation's leaf_Angle function
--==================================================================

Leaf_Move = function(date)

	tb_current_date = date
 	local Angle
	if (date < tb_RotateLeaf.StartT)
	 then
--           celestia:find("tb_rotate_leaf"):setvisible(false)
	   Angle = tb_RotateLeaf.StartPos
     	elseif (date < tb_RotateLeaf.LastT)
      	  then
	    Angle = tb_RotateLeaf.PrevPos + tb_RotateLeaf.V*(date-tb_RotateLeaf.PrevT)
	else
	  Angle = tb_RotateLeaf.LastPos
      	end
	tb_RotateLeaf.PrevT = date
	tb_RotateLeaf.PrevPos = Angle

 	return  yPi * celestia:newrotation( yAxis, Angle)

end

Leaf_Move_Angleproto =
{
   Period    = 1,
}

-- constructor method
function Leaf_Move_Angleproto:new(o)
   o = o or {}  -- create table if one not provided
   setmetatable(o, self)
   self.__index = self

   -- set the period to whatever value was specified in the ssc file;
   -- slightly confusing because Celestia is case sensitive--period must
   -- be lowercase, but the field from the ssc file is capitalized.
   o.period = o.Period

   return o
end

-- The orientation function.

function Leaf_Move_Angleproto:orientation(tjd)

	local qNow = 	Leaf_Move(tjd)
	return qNow.w, qNow.x, qNow.y, qNow.z

end

function Leaf_Move_Angle(sscvals)
   -- create a new Leaf_Move_Angle rotation object
   return Leaf_Move_Angleproto:new(sscvals)
end
